gcd

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2024 License: MIT Imports: 1 Imported by: 0

README

Greater Circle Distance Calculation

Description

4air needs a fast calculator module that multiple projects can use. The calculator will be used to calculate the distance between two points on the Earth's surface. The distance is calculated using the Great Circle Distance formula. The formula is as follows:

d = rcos-1[cos a cos b cos(x-y) + sin a sin b]

Version 0.1.0

Documentation

Index

Constants

const EARTH_RADIUS float64 = 6371

Variables

This section is empty.

Functions

func Calculate

func Calculate(lat1, long1, lat2, long2 float64) (float64, error)

Types

This section is empty.

Jump to